friendica.py
============

A python3 module to access the [friendica][1] API, as documented in the
[friendica wiki][4] at github. Additionally this module includes basic
functions to handle the [POCO][5] information of a Friendica profile. You cal
also use it to fetch information about the _new stuff_ friendica usially
notifies you about (the PING functionality).

Author: [Tobias Diekershoff][2]

Repository
----------

The repository for this module, alongside with a bugtracker and a wiki is
located at [Bitbucket][3].

License
-------

All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright
  notice, this list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above
  copyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials provided
  with the distribution.
* Neither the name of the <organization> nor the  names of its
  contributors may be used to endorse or promote products
  derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL Tobias Diekershoff BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Usage
-----

Here is a basic example of the usage of the module.

    import friendica
    # make a new instance of friendica
    f = friendica.friendica (server = 'your-friendica-node.tld',
                             username = 'your-nick',
                             password = 'some secret password')
    # check that we are logged in
    f.account_verify_credentials()

    # get the current notifications
    print (f.ping())
  
    # post something with the default settings
    f.statuses_update( status = "here is the message you are going to post" )

Additional to the official API
------------------------------

As addition to the official friendica API/POCO functionality, this module has
some wrapper functions to API calls.

**friendica.post**: is a wrapper for the statuses/update function taking the same
optional parameters, but stauts is called message because I like message more
then status.

**friendica.new_event**: also a wrapper for statuses/update but tailored to post a new
event entry to friendica. Mandatory arguments are event_summary and
event_start. See the inline docs for more details.

ToDo
----
* Test that the proxy configuration is honoured
* Support the different connectors when posting a new entry over the API.
  Currently the post_to_connector parameter of the API call is simply ignores.
* If a protocol is specified in the server name parameter of the friendica
  constructor, use it

Links
-----

[1]: http://friendica.com
[2]: http://diekershoff.net
[3]: https://bitbucket.org/tobiasd/python-friendica
[4]: https://github.com/friendica/friendica/wiki/Friendica-API
[5]: http://portablecontacts.net/
